Learn R Programming

reval (version 2.0.0)

reval-package: This package provides the function evalmany to simplify scenario testing and sensitivity analysis with R.

Description

This package provides the function evalmany to simplify scenario testing and sensitivity analysis with R.

Arguments